@@ -26,6 +26,7 @@ class Creator:
         death (date): The date of death for the creator.
         desc (str): The description of the creator.
         image (url): The url for an image associated with the creator.
+        resource_url (url): The url for the resource.
         modified (datetime): The date/time the creator was last changed.
     """
 
@@ -46,6 +47,10 @@ class CreatorSchema(Schema):
     .. versionchanged:: 2.0.2
 
         - Removed ``wikipedia`` field
+
+    .. versionchanged:: 2.3.3
+
+        - Added ``resource_url`` field.
     """
 
     id = fields.Int()
@@ -54,6 +59,7 @@ class CreatorSchema(Schema):
     death = fields.Date(allow_none=True)
     desc = fields.Str()
     image = fields.Url(allow_none=True)
+    resource_url = fields.URL()
     modified = fields.DateTime()
 
     class Meta:
