@@ -14,7 +14,15 @@ This module provides the following classes:
 """
 from marshmallow import EXCLUDE, Schema, ValidationError, fields, post_load
 
-from mokkari import arc, character, exceptions, publisher, reprint, series, team, variant
+from mokkari import exceptions
+from mokkari.arc import ArcSchema
+from mokkari.character import CharacterSchema
+from mokkari.publisher import PublisherSchema
+from mokkari.rating import RatingSchema
+from mokkari.reprint import ReprintSchema
+from mokkari.series import SeriesSchema
+from mokkari.team import TeamSchema
+from mokkari.variant import VariantSchema
 
 
 class Role:
@@ -152,6 +160,7 @@ class Issue:
         cover_date (date): The cover date of the issue.
         store_date (date, optional): The date the issue went for sale.
         price (decimal): The price of the issue.
+        rating (Rating): The issue rating.
         sku (str): Stock keeping unit for the issue.
         upc (str): UPC barcode for the issue.
         page_count (int): Number of pages for the issue.
@@ -164,6 +173,7 @@ class Issue:
         reprints (list[:obj:`Reprint`]): A list of reprinted issue contained in the issue.
         issue_name (str): The name used to identified the issue.
         variants (list[:obj:`Variant`]): A list of variant covers for the issue.
+        resource_url (url): The url for the resource.
         modified (datetime): The date/time the issue was last changed.
     """
 
@@ -209,29 +219,39 @@ class IssueSchema(Schema):
     .. versionchanged:: 2.3.0
 
         - Removed ``volume`` field. The series object will have that information.
+
+    .. versionchanged:: 2.3.2
+
+        - Added ``rating`` field.
+
+    .. versionchanged:: 2.3.3
+
+        - Added ``resource_url`` field.
     """
 
     id = fields.Int()
-    publisher = fields.Nested(publisher.PublisherSchema)
-    series = fields.Nested(series.SeriesSchema)
+    publisher = fields.Nested(PublisherSchema)
+    series = fields.Nested(SeriesSchema)
     number = fields.Str()
     collection_title = fields.Str(allow_none=True, data_key="title")
     story_titles = fields.List(fields.Str(allow_none=True), data_key="name")
     cover_date = fields.Date()
     store_date = fields.Date(allow_none=True)
     price = fields.Decimal(places=2, allow_none=True)
+    rating = fields.Nested(RatingSchema)
     sku = fields.Str()
     upc = fields.Str()
     page_count = fields.Int(allow_none=True, data_key="page")
     desc = fields.Str(allow_none=True)
     image = fields.URL(allow_none=True)
-    arcs = fields.Nested(arc.ArcSchema, many=True)
+    arcs = fields.Nested(ArcSchema, many=True)
     credits = fields.Nested(CreditsSchema, many=True)
-    characters = fields.Nested(character.CharacterSchema, many=True)
-    teams = fields.Nested(team.TeamSchema, many=True)
-    reprints = fields.Nested(reprint.ReprintSchema, many=True)
+    characters = fields.Nested(CharacterSchema, many=True)
+    teams = fields.Nested(TeamSchema, many=True)
+    reprints = fields.Nested(ReprintSchema, many=True)
     issue_name = fields.Str(data_key="issue")
-    variants = fields.Nested(variant.VariantSchema, many=True)
+    variants = fields.Nested(VariantSchema, many=True)
+    resource_url = fields.URL()
     modified = fields.DateTime()
 
     class Meta:
