@@ -25,6 +25,7 @@ class Publisher:
         founded (int): The year the publisher was founded.
         desc (str): A summary description about the publisher.
         image (url): The url for an image associated with the publisher.
+        resource_url (url): The url for the resource.
         modified (datetime): The date/time the publisher was last changed.
     """
 
@@ -45,6 +46,10 @@ class PublisherSchema(Schema):
     .. versionchanged:: 2.0.2
 
         - Removed ``wikipedia`` field
+
+    .. versionchanged:: 2.3.3
+
+        - Added ``resource_url`` field.
     """
 
     id = fields.Int()
@@ -52,6 +57,7 @@ class PublisherSchema(Schema):
     founded = fields.Int()
     desc = fields.Str()
     image = fields.Url(allow_none=True)
+    resource_url = fields.URL()
     modified = fields.DateTime()
 
     class Meta:
