@@ -16,7 +16,7 @@ from mokkari.session import Session
 
 def test_known_series(talker: Session) -> None:
     """Test for a known series."""
-    death = talker.series(1)
+    death: ser.SeriesSchema = talker.series(1)
     assert death.name == "Death of the Inhumans"
     assert death.sort_name == "Death of the Inhumans"
     assert death.volume == 1
@@ -37,6 +37,7 @@ def test_known_series(talker: Session) -> None:
         239629,
         tzinfo=timezone(timedelta(days=-1, seconds=72000), "-0400"),
     )
+    assert death.resource_url == "https://metron.cloud/series/death-of-the-inhumans-2018/"
 
 
 def test_series_without_year_end(talker: Session) -> None:
@@ -61,7 +62,7 @@ def test_serieslist(talker: Session) -> None:
     assert next(series_iter).id == 2481
     assert next(series_iter).id == 763
     assert next(series_iter).id == 93
-    assert len(series) == 150
+    assert len(series) == 162
     assert series[3].id == 93
     assert series[3].display_name == "Batman (2016)"
 
